@@ -22,6 +22,7 @@
 #include <ucommon/export.h>
 #include <ccscript.h>
 #include <ctype.h>
+#include <new>
 
 namespace ucommon {
 
@@ -325,7 +326,7 @@ void Script::errlog(unsigned line, const char *fmt, ...)
     vsnprintf(text, sizeof(text), fmt, args);
 
     ++errors;
-    caddr_t mp = (caddr_t)alloc(sizeof(Script::error));
+    void *mp = alloc(sizeof(Script::error));
     new(mp) Script::error(this, line, text);
     va_end(args);
 }
